==> ejc-zdsstore-api-3.0.0-20231224.063958-32-sources.jar: com/ejianc/business/zdsstore/vo/PickReturnDetailVO.java <==
package com.ejianc.business.zdsstore.vo;

import java.util.Date;
import java.math.*;

import com.ejianc.business.tools.refer.annotation.ReferJsonField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 材料退库明细表
 * 
 * @author generator
 * 
 */
public class PickReturnDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long storeId; // 仓库id（冗余主表仓库仓库id，便于出库查询计算）
    private String storeName; // 仓库名称
    private Long instoreId; // 主表id
    private String instoreCode; // 入库编号
    private Long instoreBillId; // 入库单id（用于穿透）
    private String outstoreCode; // 出库编号
    private Long outstoreBillId; // 出库单id（用于穿透）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date outstoreDate; // 出库时间（出库单）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date instoreDate; // 入库日期（冗余主表入库日期，便于出库查询计算）
    @ReferJsonField(referCode = "MaterialCategory001",referFields = "code",resultFields = "materialTypeCode")
    private Long materialCategoryId; // 物资分类id
    private String materialTypeCode;
    private String materialCategoryName; // 物资分类名称
    @ReferJsonField(referCode = "Material001",referFields = "code",resultFields = "materialCode")
    private Long materialId; // 物资id
    private String materialCode;
    private String materialName; // 物资名称
    private BigDecimal surplusNum; // 剩余可退数量
    private BigDecimal returnNum; // 退库数量
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 计量单位
    private String materialUnitName; // 计量单位名称
    private BigDecimal price; // 单价
    private BigDecimal mny; // 金额
    private BigDecimal taxRate; // 税率
    private BigDecimal taxPrice; // 单价(含税)
    private BigDecimal taxMny; // 金额(含税)
    private BigDecimal tax; // 税额
    private String memo; // 备注
    private Long inOutId;

    private Long wbsId; // 核算对象id
    private String wbsCode; // 核算对象code
    private String wbsName; // 核算对象name
    private Long subjectId; // 成本科目id
    private String subjectCode; // 成本科目code
    private String subjectName; // 成本科目name

    private Integer attrFlag; // 出库单物资的仓库属性 1-自购材；2-甲供材
    private String attrFlagName; //仓库属性名称

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getInstoreId() {
        return instoreId;
    }

    public void setInstoreId(Long instoreId) {
        this.instoreId = instoreId;
    }
    public String getInstoreCode() {
        return instoreCode;
    }

    public void setInstoreCode(String instoreCode) {
        this.instoreCode = instoreCode;
    }
    public Long getInstoreBillId() {
        return instoreBillId;
    }

    public void setInstoreBillId(Long instoreBillId) {
        this.instoreBillId = instoreBillId;
    }
    public String getOutstoreCode() {
        return outstoreCode;
    }

    public void setOutstoreCode(String outstoreCode) {
        this.outstoreCode = outstoreCode;
    }
    public Long getOutstoreBillId() {
        return outstoreBillId;
    }

    public void setOutstoreBillId(Long outstoreBillId) {
        this.outstoreBillId = outstoreBillId;
    }
    public Date getOutstoreDate() {
        return outstoreDate;
    }

    public void setOutstoreDate(Date outstoreDate) {
        this.outstoreDate = outstoreDate;
    }
    public Date getInstoreDate() {
        return instoreDate;
    }

    public void setInstoreDate(Date instoreDate) {
        this.instoreDate = instoreDate;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getReturnNum() {
        return returnNum;
    }

    public void setReturnNum(BigDecimal returnNum) {
        this.returnNum = returnNum;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getInOutId() {
        return inOutId;
    }

    public void setInOutId(Long inOutId) {
        this.inOutId = inOutId;
    }

    @ReferSerialTransfer(referCode = "subject-project-wbs-ref")
    public Long getWbsId() {
        return wbsId;
    }
    @ReferDeserialTransfer
    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }

    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    @ReferSerialTransfer(referCode = "subject-project-org-ref")
    public Long getSubjectId() {
        return subjectId;
    }
    @ReferDeserialTransfer
    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public Integer getAttrFlag() {
        return attrFlag;
    }

    public void setAttrFlag(Integer attrFlag) {
        this.attrFlag = attrFlag;
    }

    public String getAttrFlagName() {
        return attrFlagName;
    }

    public void setAttrFlagName(String attrFlagName) {
        this.attrFlagName = attrFlagName;
    }
}

==> ejc-zdsstore-api-3.0.0-20240109.124832-94-sources.jar: com/ejianc/business/zdsstore/vo/PickReturnDetailVO.java <==
package com.ejianc.business.zdsstore.vo;

import java.util.Date;
import java.math.*;

import com.ejianc.business.tools.refer.annotation.ReferJsonField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 材料退库明细表
 * 
 * @author generator
 * 
 */
public class PickReturnDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long storeId; // 仓库id（冗余主表仓库仓库id，便于出库查询计算）
    private String storeName; // 仓库名称
    private Long instoreId; // 主表id
    private String instoreCode; // 入库编号
    private Long instoreBillId; // 入库单id（用于穿透）
    private String outstoreCode; // 出库编号
    private Long outstoreBillId; // 出库单id（用于穿透）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date outstoreDate; // 出库时间（出库单）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date instoreDate; // 入库日期（冗余主表入库日期，便于出库查询计算）
    @ReferJsonField(referCode = "MaterialCategory001",referFields = "code",resultFields = "materialTypeCode")
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryCode; // 物资分类名称
    private String materialCategoryName; // 物资分类名称
    @ReferJsonField(referCode = "Material001",referFields = "code",resultFields = "materialCode")
    private Long materialId; // 物资id
    private String materialCode;
    private String materialName; // 物资名称
    private BigDecimal surplusNum; // 剩余可退数量
    private BigDecimal returnNum; // 退库数量
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 计量单位
    private String materialUnitName; // 计量单位名称
    private BigDecimal price; // 单价
    private BigDecimal mny; // 金额
    private BigDecimal taxRate; // 税率
    private BigDecimal taxPrice; // 单价(含税)
    private BigDecimal taxMny; // 金额(含税)
    private BigDecimal tax; // 税额
    private String memo; // 备注
    private Long inOutId;

    private Long wbsId; // 核算对象id
    private String wbsCode; // 核算对象code
    private String wbsName; // 核算对象name
    private Long subjectId; // 成本科目id
    private String subjectCode; // 成本科目code
    private String subjectName; // 成本科目name

    private Integer attrFlag; // 出库单物资的仓库属性 1-自购材；2-甲供材
    private String attrFlagName; //仓库属性名称
    private Long brandId; //品牌主键
    private String brandName; // 品牌
    private String productCode; // 产品代码

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }



    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getInstoreId() {
        return instoreId;
    }

    public void setInstoreId(Long instoreId) {
        this.instoreId = instoreId;
    }
    public String getInstoreCode() {
        return instoreCode;
    }

    public void setInstoreCode(String instoreCode) {
        this.instoreCode = instoreCode;
    }
    public Long getInstoreBillId() {
        return instoreBillId;
    }

    public void setInstoreBillId(Long instoreBillId) {
        this.instoreBillId = instoreBillId;
    }
    public String getOutstoreCode() {
        return outstoreCode;
    }

    public void setOutstoreCode(String outstoreCode) {
        this.outstoreCode = outstoreCode;
    }
    public Long getOutstoreBillId() {
        return outstoreBillId;
    }

    public void setOutstoreBillId(Long outstoreBillId) {
        this.outstoreBillId = outstoreBillId;
    }
    public Date getOutstoreDate() {
        return outstoreDate;
    }

    public void setOutstoreDate(Date outstoreDate) {
        this.outstoreDate = outstoreDate;
    }
    public Date getInstoreDate() {
        return instoreDate;
    }

    public void setInstoreDate(Date instoreDate) {
        this.instoreDate = instoreDate;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getReturnNum() {
        return returnNum;
    }

    public void setReturnNum(BigDecimal returnNum) {
        this.returnNum = returnNum;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getInOutId() {
        return inOutId;
    }

    public void setInOutId(Long inOutId) {
        this.inOutId = inOutId;
    }

    @ReferSerialTransfer(referCode = "subject-project-wbs-ref")
    public Long getWbsId() {
        return wbsId;
    }
    @ReferDeserialTransfer
    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }

    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    @ReferSerialTransfer(referCode = "subject-project-org-ref")
    public Long getSubjectId() {
        return subjectId;
    }
    @ReferDeserialTransfer
    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public Integer getAttrFlag() {
        return attrFlag;
    }

    public void setAttrFlag(Integer attrFlag) {
        this.attrFlag = attrFlag;
    }

    public String getAttrFlagName() {
        return attrFlagName;
    }

    public void setAttrFlagName(String attrFlagName) {
        this.attrFlagName = attrFlagName;
    }
}
